| Title: | a user-friendly Shiny web-service for exploration and visualization of microbiome |
|---|---|
| Description: | This shiny application provides users with an interactive and easy-to-use microbiome analysis framework. |
| Authors: | Cédric Midoux [cre, aut] (ORCID: <https://orcid.org/0000-0002-7964-0929>), Mahendra Mariadassou [ctb] (ORCID: <https://orcid.org/0000-0003-2986-354X>) |
| Maintainer: | Cédric Midoux <[email protected]> |
| License: | AGPL (>= 3) |
| Version: | 26.07 |
| Built: | 2026-07-08 15:18:18 UTC |
| Source: | https://forge.inrae.fr/migale/easy16s |
Run the Shiny Application
run_app( physeq = NULL, onStart = NULL, options = list(), enableBookmarking = NULL, uiPattern = "/", ... )run_app( physeq = NULL, onStart = NULL, options = list(), enableBookmarking = NULL, uiPattern = "/", ... )
physeq |
A |
onStart |
A function that will be called before the app is actually run.
This is only needed for |
options |
Named options that should be passed to the |
enableBookmarking |
Can be one of |
uiPattern |
A regular expression that will be applied to each |
... |
arguments to pass to golem_opts. See '?golem::get_golem_options' for more details. |